summaryrefslogtreecommitdiff
path: root/hints
diff options
context:
space:
mode:
authorJarkko Hietaniemi <jhi@iki.fi>2003-05-01 07:45:06 +0000
committerJarkko Hietaniemi <jhi@iki.fi>2003-05-01 07:45:06 +0000
commit20b634c2cddd73f32cb58e435a5061f5c6e53570 (patch)
treee6566daa2c22e5601fe014122612ccfc19caf9cb /hints
parent0f5d0394b2f5b3a7ac4dba1b324a4ccfb7799a4b (diff)
downloadperl-20b634c2cddd73f32cb58e435a5061f5c6e53570.tar.gz
z/OS: More threaded build tweaks from Brian De Pradine--
apparently now it works! p4raw-id: //depot/perl@19368
Diffstat (limited to 'hints')
-rw-r--r--hints/os390.sh8
1 files changed, 7 insertions, 1 deletions
diff --git a/hints/os390.sh b/hints/os390.sh
index 422600fe13..0873dfc83d 100644
--- a/hints/os390.sh
+++ b/hints/os390.sh
@@ -123,14 +123,20 @@ case "$ldlibpthname" in
'') ldlibpthname=LIBPATH ;;
esac
+# The folowing should always be used
+d_oldpthreads='define'
+
# Header files to include.
# You can override these with Configure -Ui_time -Ui_systime.
case "$i_time" in
'') i_time='define' ;;
esac
case "$i_systime" in
'') i_systime='define' ;;
esac
+case "$d_pthread_atfork" in
+'') d_pthread_atfork='undef' ;;
+esac
case "$d_pthread_atfork" in
'') d_pthread_atfork='undef' ;;
esac
@@ -123,14 +123,20 @@ case "$ldlibpthname" in
# Header files to include.
-# You can override these with Configure -Ui_time -Ui_systime.
+# You can override these with Configure -Ui_time -Ui_systime -Dd_pthread_atfork.
case "$i_time" in
'') i_time='define' ;;